@@ -6,7 +6,6 @@ from starlette.requests import Request
 from starlette.responses import HTMLResponse, JSONResponse, PlainTextResponse, Response
 from starlette.types import Receive, Scope, Send
 
-from strawberry.asgi.utils import get_graphiql_html
 from strawberry.exceptions import MissingQueryError
 from strawberry.file_uploads.utils import replace_placeholders_with_files
 from strawberry.http import parse_query_params, parse_request_data
@@ -14,6 +13,7 @@ from strawberry.schema import BaseSchema
 from strawberry.schema.exceptions import InvalidOperationTypeError
 from strawberry.types.graphql import OperationType
 from strawberry.utils.debug import pretty_print_graphql_operation
+from strawberry.utils.graphiql import get_graphiql_html
 
 
 class HTTPHandler:
@@ -92,8 +92,9 @@ class HTTPHandler:
                     )
             elif content_type.startswith("multipart/form-data"):
                 multipart_data = await request.form()
-                operations = json.loads(multipart_data.get("operations", "{}"))
-                files_map = json.loads(multipart_data.get("map", "{}"))
+                operations_text = multipart_data.get("operations", "{}")
+                operations = json.loads(operations_text)  # type: ignore
+                files_map = json.loads(multipart_data.get("map", "{}"))  # type: ignore
 
                 data = replace_placeholders_with_files(
                     operations, files_map, multipart_data
