@@ -36,8 +36,15 @@ from .types.fields.resolver import StrawberryResolver
 if TYPE_CHECKING:
     from .object_type import TypeDefinition
 
+T = TypeVar("T")
 
-_RESOLVER_TYPE = Union[StrawberryResolver, Callable, staticmethod, classmethod]
+
+_RESOLVER_TYPE = Union[
+    StrawberryResolver[T],
+    Callable[..., T],
+    "staticmethod[T]",
+    "classmethod[T]",
+]
 
 
 UNRESOLVED = object()
@@ -69,7 +76,7 @@ class StrawberryField(dataclasses.Field):
 
         # kw_only was added to python 3.10 and it is required
         if sys.version_info >= (3, 10):
-            kwargs["kw_only"] = False
+            kwargs["kw_only"] = dataclasses.MISSING
 
         super().__init__(
             default=(default if default is not UNSET else dataclasses.MISSING),
@@ -312,13 +319,10 @@ class StrawberryField(dataclasses.Field):
         return self._has_async_permission_classes or self._has_async_base_resolver
 
 
-T = TypeVar("T")
-
-
 @overload
 def field(
     *,
-    resolver: Callable[[], T],
+    resolver: _RESOLVER_TYPE[T],
     name: Optional[str] = None,
     is_subscription: bool = False,
     description: Optional[str] = None,
@@ -326,7 +330,7 @@ def field(
     permission_classes: Optional[List[Type[BasePermission]]] = None,
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
-    default_factory: Union[Callable, object] = UNSET,
+    default_factory: Union[Callable[..., object], object] = UNSET,
     directives: Optional[Sequence[object]] = (),
 ) -> T:
     ...
@@ -342,7 +346,7 @@ def field(
     permission_classes: Optional[List[Type[BasePermission]]] = None,
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
-    default_factory: Union[Callable, object] = UNSET,
+    default_factory: Union[Callable[..., object], object] = UNSET,
     directives: Optional[Sequence[object]] = (),
 ) -> Any:
     ...
@@ -350,7 +354,7 @@ def field(
 
 @overload
 def field(
-    resolver: _RESOLVER_TYPE,
+    resolver: _RESOLVER_TYPE[T],
     *,
     name: Optional[str] = None,
     is_subscription: bool = False,
@@ -358,27 +362,27 @@ def field(
     permission_classes: Optional[List[Type[BasePermission]]] = None,
     deprecation_reason: Optional[str] = None,
     default: Any = UNSET,
-    default_factory: Union[Callable, object] = UNSET,
+    default_factory: Union[Callable[..., object], object] = UNSET,
     directives: Optional[Sequence[object]] = (),
 ) -> StrawberryField:
     ...
 
 
 def field(
-    resolver=None,
+    resolver: Optional[_RESOLVER_TYPE[Any]] = None,
     *,
-    name=None,
-    is_subscription=False,
-    description=None,
-    permission_classes=None,
-    deprecation_reason=None,
-    default=UNSET,
-    default_factory=UNSET,
-    directives=(),
+    name: Optional[str] = None,
+    is_subscription: bool = False,
+    description: Optional[str] = None,
+    permission_classes: Optional[List[Type[BasePermission]]] = None,
+    deprecation_reason: Optional[str] = None,
+    default: Any = UNSET,
+    default_factory: Union[Callable[..., object], object] = UNSET,
+    directives: Optional[Sequence[object]] = (),
     # This init parameter is used by PyRight to determine whether this field
     # is added in the constructor or not. It is not used to change
     # any behavior at the moment.
-    init=None,
+    init: Literal[True, False, None] = None,
 ) -> Any:
     """Annotates a method or property as a GraphQL field.
 
@@ -405,7 +409,7 @@ def field(
         deprecation_reason=deprecation_reason,
         default=default,
         default_factory=default_factory,
-        directives=directives,
+        directives=directives or (),
     )
 
     if resolver:
